@@ -21,24 +21,28 @@ test_that("total probability adds up to 1", {
   allPBRseq <- getAllSeq(pbrPar(bc = blocks)) 
   allMPseq <- getAllSeq(mpPar(N, mti)) 
   allBSDseq <- getAllSeq(bsdPar(N, mti)) 
-  allEBCseq <- getAllSeq(ebcPar(N, p)) 
+  allEBCseq <- getAllSeq(ebcPar(N, p))
+  allChenseq <- getAllSeq(chenPar(N, mti, p)) 
   allTBDseq <- getAllSeq(tbdPar(bc = blocks)) 
   allHADAseq <- getAllSeq(hadaPar(N = 10))
   allRARseq <- getAllSeq(rarPar(N))
   allGBCDseq <- getAllSeq(gbcdPar(N, rho))
   allABCDseq <- getAllSeq(abcdPar(N, a))
   allBBCDseq <- getAllSeq(bbcdPar(N, gam))
+  allUDseq <- getAllSeq(udPar(N, ini = sample(0:3, 1), add = sample(4, 1)))
   
   expect_equal(sum(getProb(allCRseq)), 1)
   expect_equal(sum(getProb(allPBRseq)), 1)
   expect_equal(sum(getProb(allMPseq)), 1)
   expect_equal(sum(getProb(allBSDseq)), 1)
   expect_equal(sum(getProb(allEBCseq)), 1)
+  expect_equal(sum(getProb(allChenseq)), 1)
   expect_equal(sum(getProb(allTBDseq)), 1)
   expect_equal(sum(getProb(allHADAseq)), 1) 
   expect_equal(sum(getProb(allRARseq)), 1)
   expect_equal(sum(getProb(allGBCDseq)), 1)
   expect_equal(sum(getProb(allABCDseq)), 1)
   expect_equal(sum(getProb(allBBCDseq)), 1)
+  expect_equal(sum(getProb(allUDseq)), 1)
   
 })
